@@ -16,7 +16,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -41,8 +41,8 @@ class AKONADI_SEARCH_CORE_EXPORT SearchStore : public QObject
 {
     Q_OBJECT
 public:
-    explicit SearchStore(QObject *parent = Q_NULLPTR);
-    virtual ~SearchStore();
+    explicit SearchStore(QObject *parent = nullptr);
+    ~SearchStore() override;
 
     /**
      * Override search stores for testing
